@@ -11,7 +11,7 @@ use FindBin qw($Bin $Script);
 use File::Spec::Functions qw(catdir catfile splitdir);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -96,7 +96,7 @@ sub get_file {
 	}
 }
 
-# Reset.
+# Reset to constructor values.
 sub reset {
 	my $self = shift;
 	if ($self->{'type'} eq 'file') {
@@ -125,6 +125,19 @@ sub s {
 	}
 }
 
+# Set actual values to constructor values.
+sub set {
+	my $self = shift;
+	my @path = @{$self->{'path'}};
+	if ($self->{'type'} eq 'file') {
+		$self->{'file'} = pop @path;
+		$self->{'dir'} = \@path;
+	} else {
+		$self->{'dir'} = \@path;
+	}
+	return $self;
+}
+
 # Go to parent directory.
 sub up {
 	my ($self, $up_num) = @_;
@@ -204,6 +217,7 @@ File::Object - Object system for filesystem paths.
  my $file = $obj->get_file;
  $obj->reset;
  my $path = $obj->s;
+ $obj->set;
  $obj->up($num);
 
 =head1 METHODS
@@ -262,6 +276,10 @@ Constructor.
 
  Serialize path and return.
 
+=item C<set()>
+
+ Set actual values to constructor values.
+
 =item C<up($up_num)>
 
  Go to $up_num upper directory. 
@@ -383,6 +401,6 @@ BSD license.
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
